@@ -46,7 +46,6 @@ class DeepROC(FullROC):
 
         self.foldsNPclassRatio = None
         self.NPclassRatio      = None
-        self.priorPoint        = None
     #enddef
 
     def setPopulationPrevalence(self, populationPrevalence=None):
@@ -354,10 +353,6 @@ class DeepROC(FullROC):
         self.NPclassRatio = NPclassRatio
     #enddef
 
-    def setPriorPoint(self, priorPoint):
-        self.priorPoint = priorPoint
-    #enddef
-
     # plot() is in the superclass FullROC
 
     def plotGroupForFolds(self, plotTitle, groupIndex, foldsNPclassRatio, showError=False, showThresholds=True,
